@@ -8,6 +8,7 @@ A simple tool to start the swh-graph GRPC server in Java.
 """
 
 import logging
+import shlex
 import subprocess
 
 import aiohttp.test_utils
@@ -33,7 +34,7 @@ def spawn_java_rpc_server(config, port=None):
     print(cmd)
     # XXX: shlex.join() is in 3.8
     # logging.info("Starting RPC server: %s", shlex.join(cmd))
-    logging.info("Starting RPC server: %s", str(cmd))
+    logging.info("Starting RPC server: %s", " ".join(shlex.quote(x) for x in cmd))
     server = subprocess.Popen(cmd)
     return server, port
 
